@@ -4,7 +4,7 @@ pub use fluvio_dataplane_protocol as dataplane;
 pub use dataplane::record::{Record, RecordData};
 
 #[cfg(feature = "derive")]
-pub use fluvio_smartstream_derive::smartstream;
+pub use fluvio_smartstream_derive::{smartstream, SmartOpt};
 
 pub const ENCODING_ERROR: i32 = -1;
 
@@ -34,7 +34,6 @@ pub mod memory {
     #[allow(clippy::missing_safety_doc)]
     pub unsafe fn dealloc(ptr: *mut u8, size: usize) {
         let data = Vec::from_raw_parts(ptr, size, size);
-
         std::mem::drop(data);
     }
 }
